==> acvpproxy-1.0.0.tar.xz: acvpproxy-1.0.0/lib/request_cipher_kdf_ikev1.c <==
/* JSON request generator for SP800-135 KDF IKE v1
 *
 * Copyright (C) 2018 - 2019, Stephan Mueller <smueller@chronox.de>
 *
 * License: see LICENSE file in root directory
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, ALL OF
 * WHICH ARE HEREBY DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF NOT ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#include <errno.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "definition.h"
#include "logger.h"
#include "acvpproxy.h"
#include "internal.h"
#include "request_helper.h"

/*
 * Generate algorithm entry for KDF IKE v1
 */
int acvp_req_set_algo_kdf_ikev1(const struct def_algo_kdf_ikev1 *kdf_ikev1,
			        struct json_object *entry)
{
	struct json_object *array, *tmp;
	int ret;

	CKINT(acvp_req_add_revision(entry, "1.0"));

	CKINT(json_object_object_add(entry, "algorithm",
				     json_object_new_string("kdf-components")));
	CKINT(json_object_object_add(entry, "mode",
				     json_object_new_string("ikev1")));

	CKINT(acvp_req_gen_prereq(kdf_ikev1->prereqvals,
				  kdf_ikev1->prereqvals_num, entry));

	array = json_object_new_array();
	CKNULL(array, -ENOMEM);
	CKINT(json_object_object_add(entry, "capabilities", array));

	tmp = json_object_new_object();
	CKNULL(tmp, -ENOMEM);
	CKINT(json_object_array_add(array, tmp));

	switch(kdf_ikev1->authentication_method) {
	case DEF_ALG_KDF_IKEV1_DSA:
		CKINT(json_object_object_add(tmp, "authenticationMethod",
					     json_object_new_string("dsa")));
		break;
	case DEF_ALG_KDF_IKEV1_PSK:
		CKINT(json_object_object_add(tmp, "authenticationMethod",
					     json_object_new_string("psk")));
		break;
	case DEF_ALG_KDF_IKEV1_PKE:
		CKINT(json_object_object_add(tmp, "authenticationMethod",
					     json_object_new_string("pke")));
		break;
	default:
		json_object_put(tmp);
		logger(LOGGER_WARN, LOGGER_C_ANY,
		       "Wrong value in authentication_method\n");
		ret = -EINVAL;
		goto out;
	}

	CKINT(acvp_req_algo_int_array(tmp, kdf_ikev1->initiator_nonce_length,
				      "initiatorNonceLength"));

	CKINT(acvp_req_algo_int_array(tmp, kdf_ikev1->responder_nonce_length,
				      "responderNonceLength"));

	CKINT(acvp_req_algo_int_array(tmp,
				kdf_ikev1->diffie_hellman_shared_secret_length,
				"diffieHellmanSharedSecretLength"));

	if (kdf_ikev1->authentication_method == DEF_ALG_KDF_IKEV1_PSK) {
		if (!kdf_ikev1->pre_shared_key_length[0]) {
			logger(LOGGER_WARN, LOGGER_C_ANY,
			       "PSK pre_shared_key_length not filled in\n");
			ret = -EINVAL;
			goto out;
		}
		CKINT(acvp_req_algo_int_array(tmp,
					      kdf_ikev1->pre_shared_key_length,
					      "preSharedKeyLength"));
	}

	CKINT(acvp_req_cipher_to_array(tmp, kdf_ikev1->hashalg,
				       ACVP_CIPHERTYPE_HASH, "hashAlg"));

out:
	return ret;
}

==> acvpproxy-1.2.2.tar.xz: acvpproxy-1.2.2/lib/request_cipher_kdf_ikev1.c <==
/* JSON request generator for SP800-135 KDF IKE v1
 *
 * Copyright (C) 2018 - 2020, Stephan Mueller <smueller@chronox.de>
 *
 * License: see LICENSE file in root directory
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, ALL OF
 * WHICH ARE HEREBY DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF NOT ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#include <errno.h>
#include <stdlib.h>
#include <string.h>
#include <stdio.h>

#include "definition.h"
#include "logger.h"
#include "acvpproxy.h"
#include "internal.h"
#include "request_helper.h"

int acvp_req_set_prereq_kdf_ikev1(const struct def_algo_kdf_ikev1 *kdf_ikev1,
				  struct json_object *entry, bool publish)
{
	int ret;

	CKINT(json_object_object_add(entry, "algorithm",
				     json_object_new_string("kdf-components")));
	CKINT(json_object_object_add(entry, "mode",
				     json_object_new_string("ikev1")));

	CKINT(acvp_req_gen_prereq(kdf_ikev1->prereqvals,
				  kdf_ikev1->prereqvals_num, entry, publish));

out:
	return ret;
}

/*
 * Generate algorithm entry for KDF IKE v1
 */
int acvp_req_set_algo_kdf_ikev1(const struct def_algo_kdf_ikev1 *kdf_ikev1,
			        struct json_object *entry)
{
	struct json_object *array, *tmp;
	int ret;

	CKINT(acvp_req_add_revision(entry, "1.0"));

	CKINT(acvp_req_set_prereq_kdf_ikev1(kdf_ikev1, entry, false));

	array = json_object_new_array();
	CKNULL(array, -ENOMEM);
	CKINT(json_object_object_add(entry, "capabilities", array));

	tmp = json_object_new_object();
	CKNULL(tmp, -ENOMEM);
	CKINT(json_object_array_add(array, tmp));

	switch(kdf_ikev1->authentication_method) {
	case DEF_ALG_KDF_IKEV1_DSA:
		CKINT(json_object_object_add(tmp, "authenticationMethod",
					     json_object_new_string("dsa")));
		break;
	case DEF_ALG_KDF_IKEV1_PSK:
		CKINT(json_object_object_add(tmp, "authenticationMethod",
					     json_object_new_string("psk")));
		break;
	case DEF_ALG_KDF_IKEV1_PKE:
		CKINT(json_object_object_add(tmp, "authenticationMethod",
					     json_object_new_string("pke")));
		break;
	default:
		json_object_put(tmp);
		logger(LOGGER_WARN, LOGGER_C_ANY,
		       "Wrong value in authentication_method\n");
		ret = -EINVAL;
		goto out;
	}

	CKINT(acvp_req_algo_int_array(tmp, kdf_ikev1->initiator_nonce_length,
				      "initiatorNonceLength"));

	CKINT(acvp_req_algo_int_array(tmp, kdf_ikev1->responder_nonce_length,
				      "responderNonceLength"));

	CKINT(acvp_req_algo_int_array(tmp,
				kdf_ikev1->diffie_hellman_shared_secret_length,
				"diffieHellmanSharedSecretLength"));

	if (kdf_ikev1->authentication_method == DEF_ALG_KDF_IKEV1_PSK) {
		if (!kdf_ikev1->pre_shared_key_length[0]) {
			logger(LOGGER_WARN, LOGGER_C_ANY,
			       "PSK pre_shared_key_length not filled in\n");
			ret = -EINVAL;
			goto out;
		}
		CKINT(acvp_req_algo_int_array(tmp,
					      kdf_ikev1->pre_shared_key_length,
					      "preSharedKeyLength"));
	}

	CKINT(acvp_req_cipher_to_array(tmp, kdf_ikev1->hashalg,
				       ACVP_CIPHERTYPE_HASH, "hashAlg"));

out:
	return ret;
}
